Guidelines
=============
* The application JavaScript source code is transpiled using [Babel](https://babeljs.io/)
* We support both [SASS](http://sass-lang.com/) and [LESS](http://lesscss.org/). If you modify one in your PR, please modify both and make sure they both work.
* Additionally, when you are ready to submit your PR, please rebase your commits against the latest master branch so they are easier to examine!
* Please make sure you're not committing your re-built `dist` files, either. We'll do that!
* Also, please note, your code will not be merged if it does not pass our CI test. Thanks for your contribution!
